# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Unreleased

## 0.2.0 - 2020-01-04
### Added
- api/yaml: `Person.death_date`
- cli: `yamily-dot --comment 'some comment'`

## 0.1.0 - 2020-01-02
